icrn documentation
==================

Add your content using ``reStructuredText`` syntax. See the
`reStructuredText <https://www.sphinx-doc.org/en/master/usage/restructuredtext/index.html>`_
documentation for details.

.. automodule:: icrn.representation
   :members:

.. toctree::
   :maxdepth: 2
   :caption: Contents:

